==> veil-0.9.1.tar.gz: src/veil_funcs.h <==
/**
 * @file   veil_funcs.h
 * \code
 *     Author:       Marc Munro
 *     Copyright (c) 2005 Marc Munro
 *     License:      BSD
 * $Id: veil_funcs.h,v 1.2 2005/10/04 22:16:15 bloodnok Exp $
 * \endcode
 * @brief  
 * Provide definitions for all non-local C-callable Veil functions.
 * 
 */

#include "veil_datatypes.h"

// veil_utils
extern void *vl_malloc(size_t size);
char *vl_ObjTypeName(ObjType obj);


// veil_variables
extern VarEntry *vl_lookup_shared_variable(char *name);
extern VarEntry *vl_lookup_variable(char *name);
extern veil_variable_t *vl_next_variable(veil_variable_t *prev);
extern void vl_ClearInt4Array(Int4Array *array);
extern Int4Array *vl_NewInt4Array(Int4Array *current, bool shared,
								  int32 min, int32 max);
extern void vl_Int4ArraySet(Int4Array *array, int32 idx, int32 value);
extern int32 vl_Int4ArrayGet(Int4Array *array, int32 idx);


// veil_datatypes
extern Range *vl_NewRange(bool shared);
extern Int4Var *vl_NewInt4(bool shared);

// veil_bitmap
extern void vl_ClearBitmap(Bitmap *bitmap);
extern void vl_NewBitmap(Bitmap **p_bitmap, bool shared, int32 min, int32 max);
extern void vl_BitmapSetbit(Bitmap *bitmap, int32 bit);
extern void vl_BitmapClearbit(Bitmap *bitmap, int32 bit);
extern bool vl_BitmapTestbit(Bitmap *bitmap, int32 bit);
extern void vl_BitmapUnion(Bitmap *target,	Bitmap *source);
extern void vl_BitmapIntersect(Bitmap *target,	Bitmap *source);
extern int32 vl_BitmapNextBit(Bitmap *bitmap, int32 bit, bool *found);
extern Bitmap *vl_BitmapFromArray(BitmapArray *bmarray, int32 elem);
extern void vl_ClearBitmapArray(BitmapArray *bmarray);
extern void vl_NewBitmapArray(BitmapArray **p_bmarray, bool shared,
							  int32 arrayzero, int32 arraymax,
							  int32 bitzero, int32 bitmax);
extern VarEntry *vl_NextHashEntry(HTAB *hash, VarEntry *prev);
extern void vl_NewBitmapHash(BitmapHash **p_bmhash, char *name,
							 int32 bitzero, int32 bitmax);
extern Bitmap *vl_BitmapFromHash(BitmapHash *bmhash, char *hashelem);
extern Bitmap *vl_AddBitmapToHash(BitmapHash *bmhash, char *hashelem);

// veil_shmem
extern HTAB *vl_get_shared_hash();
extern bool vl_prepare_context_switch();
extern bool vl_complete_context_switch();
extern void vl_force_context_switch();
extern void *vl_shmalloc(size_t size);
extern void vl_free(void *mem);

// veil_query
extern bool vl_bool_from_query(const char *qry, bool *result);

==> veil-0.9.2.tar.gz: src/veil_funcs.h <==
/**
 * @file   veil_funcs.h
 * \code
 *     Author:       Marc Munro
 *     Copyright (c) 2005, 2006 Marc Munro
 *     License:      BSD
 * $Id: veil_funcs.h,v 1.3 2006/10/04 15:50:09 bloodnok Exp $
 * \endcode
 * @brief  
 * Provide definitions for all non-local C-callable Veil functions.
 * 
 */

#include "veil_datatypes.h"

// veil_utils
extern void *vl_malloc(size_t size);
char *vl_ObjTypeName(ObjType obj);


// veil_variables
extern VarEntry *vl_lookup_shared_variable(char *name);
extern VarEntry *vl_lookup_variable(char *name);
extern veil_variable_t *vl_next_variable(veil_variable_t *prev);
extern void vl_ClearInt4Array(Int4Array *array);
extern Int4Array *vl_NewInt4Array(Int4Array *current, bool shared,
								  int32 min, int32 max);
extern void vl_Int4ArraySet(Int4Array *array, int32 idx, int32 value);
extern int32 vl_Int4ArrayGet(Int4Array *array, int32 idx);


// veil_datatypes
extern Range *vl_NewRange(bool shared);
extern Int4Var *vl_NewInt4(bool shared);

// veil_bitmap
extern void vl_ClearBitmap(Bitmap *bitmap);
extern void vl_NewBitmap(Bitmap **p_bitmap, bool shared, int32 min, int32 max);
extern void vl_BitmapSetbit(Bitmap *bitmap, int32 bit);
extern void vl_BitmapClearbit(Bitmap *bitmap, int32 bit);
extern bool vl_BitmapTestbit(Bitmap *bitmap, int32 bit);
extern void vl_BitmapUnion(Bitmap *target,	Bitmap *source);
extern void vl_BitmapIntersect(Bitmap *target,	Bitmap *source);
extern int32 vl_BitmapNextBit(Bitmap *bitmap, int32 bit, bool *found);
extern Bitmap *vl_BitmapFromArray(BitmapArray *bmarray, int32 elem);
extern void vl_ClearBitmapArray(BitmapArray *bmarray);
extern void vl_NewBitmapArray(BitmapArray **p_bmarray, bool shared,
							  int32 arrayzero, int32 arraymax,
							  int32 bitzero, int32 bitmax);
extern VarEntry *vl_NextHashEntry(HTAB *hash, VarEntry *prev);
extern void vl_NewBitmapHash(BitmapHash **p_bmhash, char *name,
							 int32 bitzero, int32 bitmax);
extern Bitmap *vl_BitmapFromHash(BitmapHash *bmhash, char *hashelem);
extern Bitmap *vl_AddBitmapToHash(BitmapHash *bmhash, char *hashelem);

// veil_shmem
extern HTAB *vl_get_shared_hash(void);
extern bool vl_prepare_context_switch(void);
extern bool vl_complete_context_switch(void);
extern void vl_force_context_switch(void);
extern void *vl_shmalloc(size_t size);
extern void vl_free(void *mem);
extern void _PG_init(void);

// veil_query
extern bool vl_bool_from_query(const char *qry, bool *result);

// veil_config
extern void veil_config_init(void);
extern int veil_shared_hash_elems(void);
extern int veil_shmem_chunk_size(void);
extern int veil_shmem_context_size(void);
